"use strict";
/*
 * Copyright (c) 2019, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const metadataApi_1 = require("../metadataApi");
const types_1 = require("../types");
const utils_1 = require("../utils");
const fileSystemHandler_1 = require("../utils/fileSystemHandler");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/sfdx-diff', 'diff');
const MD_TYPE_LAYOUT = 'Layout';
class LayoutProcessor {
    constructor(metadataInfo, connection) {
        this.metadataInfo = metadataInfo;
        this.connection = connection;
        this.cacheFolder = 'layouts';
    }
    async getMetadata() {
        const cachedFilePath = await this.getCachedFilePath();
        try {
            metadataApi_1.metadataApiService.initialize(this.connection);
            const request = metadataApi_1.metadataApiService.buildRetrieveRequest(MD_TYPE_LAYOUT, this.metadataInfo.fileName);
            const retrieveID = await metadataApi_1.metadataApiService.metadataRetrieveID(request);
            const mdResult = await metadataApi_1.metadataApiService.metadataRetrievePoll(retrieveID, 3000, 100);
            if (mdResult.status === types_1.RetrieveStatusEnum.Succeeded) {
                if (mdResult.messages && mdResult.messages.problem) {
                    throw new Error(mdResult.messages.problem);
                }
                const fileFromZip = metadataApi_1.metadataApiService.getFileFromZipFile(mdResult.zipFile, this.getMdFileName());
                fileSystemHandler_1.createMdCacheFile(cachedFilePath, fileFromZip);
            }
        }
        catch (err) {
            throw new Error(messages.getMessage('error_in_processor', ['LayoutProcessor', err]));
        }
        return cachedFilePath;
    }
    async getCachedFilePath() {
        return await utils_1.createCacheFilePath(this.cacheFolder, this.getMdFileName());
    }
    getMdFileName() {
        return `${this.metadataInfo.fileName}.${this.metadataInfo.suffix}`;
    }
}
exports.default = LayoutProcessor;
//# sourceMappingURL=layoutProcessor.js.map