"use strict";
/*
 * Copyright (c) 2019, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const usernameHandler_1 = require("./usernameHandler");
const os = require("os");
function getAbsolutePath(sourcePath) {
    return path.resolve(sourcePath);
}
exports.getAbsolutePath = getAbsolutePath;
function getDiffCacheRootPath() {
    return os.tmpdir();
}
exports.getDiffCacheRootPath = getDiffCacheRootPath;
async function createCacheFilePath(parentFolder, fileName) {
    const usernameHandler = usernameHandler_1.UsernameHandler.getInstance();
    const username = await usernameHandler.getUsername();
    const rootPath = getDiffCacheRootPath();
    return path.join(rootPath, '.sfdx', 'orgs', username, 'diffCache', parentFolder, fileName);
}
exports.createCacheFilePath = createCacheFilePath;
async function createBundleCacheFilePath(parentFolder, bundleName, fileName) {
    const usernameHandler = usernameHandler_1.UsernameHandler.getInstance();
    const username = await usernameHandler.getUsername();
    const rootPath = getDiffCacheRootPath();
    return path.join(rootPath, '.sfdx', 'orgs', username, 'diffCache', parentFolder, bundleName, fileName);
}
exports.createBundleCacheFilePath = createBundleCacheFilePath;
function createMdCacheFile(cacheFilePath, fileContent) {
    this.ensureDirectoryExists(cacheFilePath);
    const writeStream = fs.createWriteStream(cacheFilePath);
    writeStream.write(fileContent);
    writeStream.end();
    return cacheFilePath;
}
exports.createMdCacheFile = createMdCacheFile;
function ensureDirectoryExists(filePath) {
    const dirname = path.dirname(filePath);
    if (fs.existsSync(dirname)) {
        return true;
    }
    this.ensureDirectoryExists(dirname);
    fs.mkdirSync(dirname);
}
exports.ensureDirectoryExists = ensureDirectoryExists;
//# sourceMappingURL=fileSystemHandler.js.map